// (c) Thomas Kamps, 2009
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#include <stdlib.h>
#include <time.h>

#include "player.h"

Player::Player(int i) {
	id = i;
	game = -1;
	name = "No name";
	avatar = "";
	money = 0;
	pos = 0;
	inJail = false;
	hasTurn = false;
	canRoll = false;
	canBuyEstate = false;
	host = "";
	master = false;
	spectator = false;
	hasDept = false;
	canAuction = false;
	canUseCard = false;

	QColor col;
	int h = (rand() % (360));
	int s = 192+(rand() % (64));
	int v = 128+(rand() % (32));
	col.setHsv(h,s,v);
	int r = col.red();
	int g = col.green();
	int b = col.blue();

	QString sr = QString::number(r,16);
	QString sg = QString::number(g,16);
	QString sb = QString::number(b,16);
	if (sr.size() < 2) sr = "0"+sr;
	if (sg.size() < 2) sg = "0"+sg;
	if (sb.size() < 2) sb = "0"+sb;
	chatColor = "#"+sr+sg+sb;

	playerWidget = new PlayerInfo(0, 32);
	playerWidget->setName(name);
	playerWidget->setMoney(QString(0));
	playerWidget->setAvatar(avatar);

	auction = new PlayerAuction();
	auction->setName(name);
	auction->setMoney(QString(0));
	auction->setAvatar(avatar);

	playerWidget->playerId = id;
	auction->playerId = id;
}

Player::~Player() {
	delete playerWidget;
	delete auction;
}

int Player::getId() {
	return id;
}

int Player::getGame() {
	return game;
}

QString Player::getName() {
	return name;
}

QString Player::getAvatar() {
	return avatar;
}

int Player::getMoney() {
	return money;
}

int Player::getPos() {
	return pos;
}

bool Player::getInJail() {
	return inJail;
}

bool Player::getHasTurn() {
	return hasTurn;
}

bool Player::getCanRoll() {
	return canRoll;
}

bool Player::getCanBuyEstate() {
	return canBuyEstate;
}

QString Player::getHost() {
	return host;
}

bool Player::getMaster() {
	return master;
}

bool Player::getSpectator() {
	return spectator;
}

bool Player::getHasDept() {
	return hasDept;
}

bool Player::getCanAuction() {
	return canAuction;
}

bool Player::getCanUseCard() {
	return canUseCard;
}

bool Player::getBankrupt() {
	return bankrupt;
}

QString Player::getChatColor() {
	return chatColor;
}

void Player::setGame(int g) {
	game= g;
	if (game == -1) playerWidget->setMoney("");
	else playerWidget->setMoney(QString::number(money));
}

void Player::setName(QString n) {
	name = n;
	setHasTurn(hasTurn);
	auction->setName(n);
}

void Player::setAvatar(QString a) {
	avatar = a;
	playerWidget->setAvatar(a);
	auction->setAvatar(a);
}

void Player::setMoney(int m) {
	money = m;
	if (game != -1)
		playerWidget->setMoney(QString::number(money));
	else
		playerWidget->setMoney("");
}

void Player::setPos(int p) {
	pos = p;
}

void Player::setInJail(bool j) {
	inJail = j;
	playerWidget->setJailed(j);
}

void Player::setHasTurn(bool ht) {
	hasTurn = ht;
	if (hasTurn) playerWidget->setName("<b>"+name+"</b>");
	else playerWidget->setName(name);
}

void Player::setCanRoll(bool cr) {
	canRoll = cr;
}

void Player::setCanBuyEstate(bool cbe) {
	canBuyEstate = cbe;
}

void Player::setHost(QString h) {
	host = h;
}

void Player::setMaster(bool m) {
	master = m;
}

void Player::setSpectator(bool s) {
	spectator = s;
}

void Player::setHasDept(bool hd) {
	hasDept = hd;
}

void Player::setCanAuction(bool ca) {
	canAuction = ca;
}

void Player::setCanUseCard(bool cuc) {
	canUseCard = cuc;
}

void Player::setBankrupt(bool b) {
	bankrupt = b;
}

void Player::setPlayerWidgetVisible(bool vis) {
	playerWidget->setVisible(vis);
	auction->setVisible(vis);
}
